%* lsaf_createworkspacefolder                                                              *;
%*                                                                                         *;
%* Creates a folder in the workspace of the current user.                                  *;
%*                                                                                         *;
%* All parent folders that do not exist are created.                                       *;
%*                                                                                         *;
%* Syntax:                                                                                 *;
%* %LSAF_CREATEWORKSPACEFOLDER(LSAF_PATH=lsaf-path);                                       *;
%*                                                                                         *;
%* @macvar _lsafRC_  The return code.                                                      *;
%* @macvar _lsafMsg_ The return message.                                                   *;
%*                                                                                         *;
%* @param lsaf_path - Required - The path to the folder.                                   *;
%*                                                                                         *;
%* @macrotype LSAF                                                                         *;
%* @since 1.5                                                                              *;
%* @exposure external                                                                      *;
%*                                                                                         *;
%* @history 2016-09-29  initial coding                                                     *;
%* @history 2019-03-04  update to 2.1                                                      *;
%*                                                                                         *;

%macro lsaf_createworkspacefolder(
  lsaf_path=
  ) /des='Create a folder in the SAS Life Science Analytics Framework workspace.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsgPrimary    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj cmd("com/sas/lsaf/macro/service/WorkspaceService");
    declare javaobj results("com/sas/lsaf/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    cmd.callStaticVoidMethod("createFolder", "%bquote(&lsaf_path)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    logMsgPrimary=logMsgPrefix;
    logMsg=" The folder was created in the workspace: &lsaf_path" ;
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" The folder was not created in the workspace: &lsaf_path" ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrimary " " logMsg;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_createworkspacefolder ;
