%* lsaf_deleteprocessflow                                                                         *;
%*                                                                                                *;
%* Deletes a process flow.                                                                        *;
%*                                                                                                *;
%* Syntax:                                                                                        *;
%* %LSAF_DELETEPROCESSFLOW(LSAF_PATH=lsaf-path, LSAF_PROCESSFLOW=process-flow-name);              *;
%*                                                                                                *;
%* @macvar _lsafRC_  The return code.                                                             *;
%* @macvar _lsafMsg_ The return message.                                                          *;
%*                                                                                                *;
%* @param lsaf_path - Required - The path of the context in which the process flow is located.    *;
%* @param lsaf_processflow - Required - The name of the process flow.                             *;
%*                                                                                                *;
%* @macrotype LSAF                                                                                *;
%* @since 1.5                                                                                     *;
%* @exposure external                                                                             *;
%*                                                                                                *;
%* @history 2016-11-16  initial programming                                                       *;
%* @history 2019-02-12  update to 2.1                                                             *;
%*                                                                                                *;

%macro lsaf_deleteprocessflow(
  lsaf_path=,
  lsaf_processflow=
  ) /des='Delete a process flow';

  %******************************;
  %* Initialize macro variables *;
  %******************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %********************************************;
  %* Start the datastep to call the java code *;
  %********************************************;
  data _null_;
    attrib returnCode     length=8
           message        length=$200
           logMsgPrefix   length=$70
           logMsgPrimary  length=$70
           logMsg         length=$300
    ;

    %****************************;
    %* Declare the java objects *;
    %****************************;
    declare javaobj srv("com/sas/lsaf/macro/service/ProcessFlowService");
    declare javaobj results("com/sas/lsaf/macro/results/Result");

    %*************************;
    %* Attempt the operation *;
    %*************************;
    srv.callStaticVoidMethod("delete", "%bquote(&lsaf_path)", "%bquote(&lsaf_processflow)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************;
    %* Process the results *;
    %***********************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot delete the process flow &lsaf_processflow.." ;
    end;
    else
    do;
      logMsgPrimary=logMsgPrefix;
      logMsg=" The process flow &lsaf_processflow was deleted." ;
    end;

    %*************************;
    %* Print messages in log *;
    %*************************;
    put;
    put logMsgPrimary " " logMsg;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***************************;
    %* Set the macro variables *;
    %***************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_deleteprocessflow;
