%* lsaf_lockuser                                                                           *;
%*                                                                                         *;
%* Locks a user account.                                                                   *;
%*                                                                                         *;
%* The person who runs the macro must have the user account privilege Manage User Accounts.*;
%*                                                                                         *;
%* Syntax:                                                                                 *;
%* %LSAF_LOCKUSER(LSAF_USERID=lsaf-userid);                                                *;
%*                                                                                         *;
%* @macvar _lsafRC_  The return code.                                                      *;
%* @macvar _lsafMsg_ The return message.                                                   *;
%*                                                                                         *;
%* @param lsaf_userid - Required - The user identifier of the user account.                *;
%*                                                                                         *;
%* @macrotype LSAF                                                                         *;
%* @since 1.4                                                                              *;
%* @exposure external                                                                      *;
%*                                                                                         *;
%* @history 2014-3-19 initial coding                                                       *;
%* @history 2016-08-26  rebrand as LSAF                                                    *;
%*                                                                                         *;

%macro lsaf_lockuser(
  lsaf_userid=
  ) /des='Locks a user account.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_ =%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsgPrimary   length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/lsaf/macro/service/UserService");
    declare javaobj results("com/sas/lsaf/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("lockUser", "%bquote(&lsaf_userid)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot lock account for user &lsaf_userid.";
    end;
    else
    do;
      logMsgPrimary=logMsgPrefix;
      logMsg=" Locked account for user &lsaf_userid.";
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrimary " " logMsg;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_lockuser ;
