%* lsaf_resetpassword                                                                            *;
%*                                                                                               *;
%* Resets the password for a user account.                                                       *;
%*                                                                                               *;
%* The person who runs the macro must have the user account privilege Manage User Accounts.      *;
%* After the password has been successfully reset, the user can immediately log on with the new  *;
%* password. But, the user is required to immediately change the password so that the password   *;
%* remains known only to the user.                                                               *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %LSAF_RESETPASSWORD(LSAF_USERID=lsaf-userid, LSAF_NEWPASSWORD=lsaf-password);                 *;
%*                                                                                               *;
%* @macvar _lsafRC_  The return code.                                                            *;
%* @macvar _lsafMsg_ The return message.                                                         *;
%*                                                                                               *;
%* @param lsaf_userid - Required - The user identifier of the account.                           *;
%* @param lsaf_newpassword - Required - The new, temporary password.                             *;
%*                                                                                               *;
%* @macrotype LSAF                                                                               *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-11-04 initial coding                                                            *;
%* @history 2016-08-26  rebrand as LSAF                                                          *;
%*                                                                                               *;

%macro lsaf_resetpassword(
  lsaf_userid=,
  lsaf_newpassword=
  ) /des='Reset the password for an account in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsgPrimary   length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/lsaf/macro/service/UserService");
    declare javaobj results("com/sas/lsaf/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("resetPassword", "%bquote(&lsaf_userid)", "%bquote(&lsaf_newpassword)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    if (returnCode eq 0) then
    do;
      logMsgPrimary=logMsgPrefix;
      logMsg=" The password for the account &lsaf_userid was successfully reset." ;
    end;
      else
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Unable to reset the password for the account &lsaf_userid.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrimary " " logMsg;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_resetpassword;
