%* lsaf_setuserextauthenticator                                                                  *;                                                                                                                                                                                                                                       
%*                                                                                               *;                                                                                                                                                                                                                                       
%* Sets the external authenticator for the user account. To change a user account back to a      *;
%* default state, call the %lsaf_setuserdefaultauthenticator macro.                              *;   
%*                                                                                               *;                                                                                                                                                                                                                                       
%* Syntax:                                                                                       *;                                                                                                                                                                                                                                       
%* %LSAF_SETUSEREXTAUTHENTICATOR(LSAF_USERID=lsaf-userid,                                        *;
%*         LSAF_AUTHENTICATORID=lsaf-authenticatorid,                                            *;
%*         <LSAF_AUTHENTICATORNAME=lsaf-authenticatorname>);                                     *;
%*                                                                                               *;                                                                                                                                                                                                                                       
%* @macvar _lsafRC_  The return code.                                                            *;                                                                                                                                                                                                                                       
%* @macvar _lsafMsg_ The return message.                                                         *;                                                                                                                                                                                                                                       
%*                                                                                               *;                                                                                                                                                                                                                                       
%* @param lsaf_userid - Required - The unique identifier of the user account.                    *;
%* @param lsaf_authenticatorid - Required - The unique identifier of the external authenticator. *;
%*         This value can be retrieved by calling the lsaf_getuserauthproviders macro.           *;        
%* @param lsaf_authenticatorname - Optional - The user name known to the external authenticator. *;
%*                                                                                               *;                                                                                                                                                                                                                                       
%* @macrotype LSAF                                                                               *;                                                                                                                                                                                                                                       
%* @since 2.3                                                                                    *;                                                                                                                                                                                                                                       
%* @exposure external                                                                            *;                                                                                                                                                                                                                                       
%*                                                                                               *;                                                                                                                                                                                                                                       
%* @history 2019-12-16  Initial coding                                                           *;
%*                                                                                               *;                                                                                                                                                                                                                                       
                                                                                                                                                                                                                                                                                                                                     
%macro lsaf_setuserextauthenticator(
  lsaf_userid=, 
  lsaf_authenticatorid=,
  lsaf_authenticatorname=
  ) /des='Sets the external authenticator for a user.';                                                                                                                                                                                                                                                                                 
                                                                                                                                                                                                                                                                                                                                     
  %****************************************;                                                                                                                                                                                                                                                                                         
  %* Initialize macro variables           *;                                                                                                                                                                                                                                                                                         
  %****************************************;                                                                                                                                                                                                                                                                                         
  %lsaf_getproductname();                                                                                                                                                                                                                                                                                                            
                                                                                                                                                                                                                                                                                                                                     
  %global _lsafMsg_
          _lsafRC_                                                                                                                                                                                                                                                                                                                   
  ;                                                                                                                                                                                                                                                                                                                                  
                                                                                                                                                                                                                                                                                                                                     
  %let _lsafRC_ =%str(-999);                                                                                                                                                                                                                                                                                                         
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);                                                                                                                                                                                                                                                
                                                                                                                                                                                                                                                                                                                                     
  %**********************************************;                                                                                                                                                                                                                                                                                   
  %* Start the datastep to call the java code   *;                                                                                                                                                                                                                                                                                   
  %**********************************************;                                                                                                                                                                                                                                                                                   
  data _null_;                                                                                                                                                                                                                                                                                                                       
    attrib returnCode      length=8;                                                                                                                                                                                                                                                                                                 
    attrib message         length=$200;                                                                                                                                                                                                                                                                                              
    attrib logMsgPrefix    length=$70;                                                                                                                                                                                                                                                                                               
    attrib logMsgPrimary   length=$70;                                                                                                                                                                                                                                                                                               
    attrib logMsg          length=$300;                                                                                                                                                                                                                                                                                              
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Declare the java objects        *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    declare javaobj srv("com/sas/lsaf/macro/service/UserService");                                                                                                                                                                                                                                                              
    declare javaobj results("com/sas/lsaf/macro/results/Result");                                                                                                                                                                                                                                                                     
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Attempt the operation           *:                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    srv.callStaticVoidMethod("setExternalAuthenticator", "%bquote(&lsaf_userid)", "%bquote(&lsaf_authenticatorid)", "%bquote(&lsaf_authenticatorname)", results);                          
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Retrieve the results            *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    results.callIntMethod("getReturnCode", returnCode);                                                                                                                                                                                                                                                                              
    results.callStringMethod("getReturnMessage", message);                                                                                                                                                                                                                                                                           
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Process the results             *;                                                                                                                                                                                                                                                                                            
    %***********************************; 
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    logMsgPrimary=logMsgPrefix;
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Setting the user external authenticator was unsuccessful for &lsaf_userid";
    end;
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Print messages in log           *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    put;                                                                                                                                                                                                                                                                                                                             
    put logMsgPrimary " " logMsg;                                                                                                                                                                                                                                                                                                     
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));                                                                                                                                                                                                                                                                         
    put logMsgPrefix " _lsafMsg_= " message;                                                                                                                                                                                                                                                                                         
    put logMsgPrefix " _lsafRC_= " returnCode;                                                                                                                                                                                                                                                                                       
    put;                                                                                                                                                                                                                                                                                                                             
                                                                                                                                                                                                                                                                                                                                     
    %***********************************;                                                                                                                                                                                                                                                                                            
    %* Set the macro variables         *;                                                                                                                                                                                                                                                                                            
    %***********************************;                                                                                                                                                                                                                                                                                            
    call symputx("_lsafRC_", returnCode);                                                                                                                                                                                                                                                                                            
    call symputx("_lsafMsg_", message);                                                                                                                                                                                                                                                                                              
                                                                                                                                                                                                                                                                                                                                     
  run;                                                                                                                                                                                                                                                                                                                               
                                                                                                                                                                                                                                                                                                                                     
%mend lsaf_setuserextauthenticator;                                                                                                                                                                                                                                                                                                            
