%* lsaf_unlockfile                                                                         *;
%*                                                                                         *;
%* Unlocks a file that is in the repository.                                               *;
%*                                                                                         *;
%* The person who runs the macro must have the Manage Locking role privilege.              *;
%*                                                                                         *;
%* Syntax:                                                                                 *;
%* %LSAF_UNLOCKFILE(LSAF_PATH=lsaf-path);                                                  *;
%*                                                                                         *;
%* @macvar _lsafRC_  The return code.                                                      *;
%* @macvar _lsafMsg_ The return message.                                                   *;
%*                                                                                         *;
%* @param lsaf_path - Required - The path of the file.                                     *;
%*                                                                                         *;
%* @macrotype LSAF                                                                         *;
%* @since 2.3                                                                              *;
%* @exposure external                                                                      *;
%*                                                                                         *;
%* @history 2020-01-22 initial coding                                                      *;
%*                                                                                         *;

%macro lsaf_unlockfile(
  lsaf_path=
  ) /des='Unlocks a file.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_ =%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsgPrimary   length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/lsaf/macro/service/RepositoryService");
    declare javaobj results("com/sas/lsaf/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("unlockFile", "%bquote(&lsaf_path)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    if (returnCode ne 0) then
    do;
      logMsgPrimary="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot unlock file: &lsaf_path..";
    end;
    else
    do;
      logMsgPrimary=logMsgPrefix;
      logMsg=" Unlocked file: &lsaf_path..";
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrimary " " logMsg;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_unlockfile;
